==> ssp-center-api-0.1.24-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/RspSlotBackendDetailDto.java <==
/**
 * Project Name:media-api<br>
 * File Name:RspSlotDetailDto.java<br>
 * Package Name:cn.com.duiba.tuia.media.api.dto.rsp<br>
 * Date:2016年10月14日上午9:45:25<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.List;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName: RspSlotDetailDto <br/>
 * date: 2016年10月14日 上午9:45:26 <br/>
 * .
 *
 * @author xiawei
 * @version
 * @since JDK 1.6
 */
public class RspSlotBackendDetailDto implements Serializable {

	/**
     * @since JDK 1.6
     */
    private static final long serialVersionUID  = -1368433294004913036L;

    /** 广告位ID. */
    private Long              slotId;

    /** 广告位名称. */
    private String            slotName;

    /** 广告位类型. */
    private Integer           slotType;

    /** 媒体ID. */
    private Long              appId;

    /** 媒体名称. */
    private String            appName;

    /** 主图尺寸 0-600*300 1-600*500 2-640*270 3-960*640 4-800*120. */
    private Integer           pictureSize;

    /** 广告信息流类型 */
    private Integer           flowType;

    /** 屏蔽策略ID. */
    private Long              strategyId;

    /** 屏蔽策略名称. */
    private String            strategyName;

    /** 屏蔽行业. */
    private List<TagLevel>    shieldIndustries;

    /** 屏蔽广告主. */
    private List<String>      shieldAdvertisers;

    /** 屏蔽广告列表. */
    private List<TagLevel>    advertTagNums;

    /** 屏蔽活动标签列表 */
    private List<TagLevel>    shieldActivitys;

    /** The industry flag. */
    private boolean           industryFlag      = false;

    /** The advertiser flag. */
    private boolean           advertiserFlag    = false;

    /** The advertTagNums flag. */
    private boolean           advertTagNumsFlag = false;
    
    /** The activitys flag. */
    private boolean           activitysFlag     = false;

    /** 广告位曝光上限 */
    private Integer           slotExposeLimit;

    /** 活动曝光上限 */
    private Integer           activityExposeLimit;

    /** 手动投放时的活动投放地址. */
    private String            activityUrl;

    /** 手动投放时的活动投放目标地址. */
    private String            activityTargetUrl;

    /** 小图标是否可见. */
    private boolean           isVisibleOfIco;

    /** 关闭按钮是否可见. */
    private boolean           isVisibleOfCloseButton;

    /** 关联规格名称 */
    private String            msName;
    
    /** 是否拦截返回操作(1:拦截，0:不拦截). */
    private Boolean            isReturn;

    /** 拦截返回操作频次. */
    private Integer            numReturn;
    
    /** 推荐位弹层开关(1:开，0:关). */
    private Boolean            isRecommend;
    
    /** 广告位投放方式 */
    private Integer    		  activityPutWay;

    /** sdk版本list */
    private List<String>      sdkVersions;

    /** sdk来源信息list */
    private List<String>      sdkSources;

    /** sdk类型 */
    private String            sdkType;

    /** app 审核状态 */
    private Integer           appStatus;

    /** 广告位定向模式 1：仅投放定向列表 2：优先投放定向列表 */
    private Integer           directMode;
    
    /**管理端屏蔽策略标签*/
    private Long              managerStrategyId;

    /** 来源域名屏蔽策略名称*/
    private List<String> shieldName;

    /** 媒体平台*/
    private String   platform ;

    private String remark;

    private List<String> remarkImgs;

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public List<String> getRemarkImgs() {
        return remarkImgs;
    }

    public void setRemarkImgs(List<String> remarkImgs) {
        this.remarkImgs = remarkImgs;
    }

    /**
     * industryFlag.
     *
     * @return the industryFlag
     * @since JDK 1.6
     */
    public boolean isIndustryFlag() {
        return industryFlag;
    }

    /**
     * industryFlag.
     *
     * @param industryFlag the industryFlag to set
     * @since JDK 1.6
     */
    public void setIndustryFlag(boolean industryFlag) {
        this.industryFlag = industryFlag;
    }

    /**
     * advertiserFlag.
     *
     * @return the advertiserFlag
     * @since JDK 1.6
     */
    public boolean isAdvertiserFlag() {
        return advertiserFlag;
    }

    /**
     * advertiserFlag.
     *
     * @param advertiserFlag the advertiserFlag to set
     * @since JDK 1.6
     */
    public void setAdvertiserFlag(boolean advertiserFlag) {
        this.advertiserFlag = advertiserFlag;
    }

    /**
     * slotType.
     *
     * @return the slotType
     * @since JDK 1.6
     */
    public Integer getSlotType() {
        return slotType;
    }

    /**
     * slotType.
     *
     * @param slotType the slotType to set
     * @since JDK 1.6
     */
    public void setSlotType(Integer slotType) {
        this.slotType = slotType;
    }

    /**
     * slotId.
     *
     * @return the slotId
     * @since JDK 1.6
     */
    public Long getSlotId() {
        return slotId;
    }

    /**
     * slotId.
     *
     * @param slotId the slotId to set
     * @since JDK 1.6
     */
    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    /**
     * slotName.
     *
     * @return the slotName
     * @since JDK 1.6
     */
    public String getSlotName() {
        return slotName;
    }

    /**
     * slotName.
     *
     * @param slotName the slotName to set
     * @since JDK 1.6
     */
    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    /**
     * appId.
     *
     * @return the appId
     * @since JDK 1.6
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * appId.
     *
     * @param appId the appId to set
     * @since JDK 1.6
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * appName.
     *
     * @return the appName
     * @since JDK 1.6
     */
    public String getAppName() {
        return appName;
    }

    /**
     * appName.
     *
     * @param appName the appName to set
     * @since JDK 1.6
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }

    /**
     * pictureSize.
     *
     * @return the pictureSize
     * @since JDK 1.6
     */
    public Integer getPictureSize() {
        return pictureSize;
    }

    /**
     * pictureSize.
     *
     * @param pictureSize the pictureSize to set
     * @since JDK 1.6
     */
    public void setPictureSize(Integer pictureSize) {
        this.pictureSize = pictureSize;
    }

    /**
     * strategyId.
     *
     * @return the strategyId
     * @since JDK 1.6
     */
    public Long getStrategyId() {
        return strategyId;
    }

    /**
     * strategyId.
     *
     * @param strategyId the strategyId to set
     * @since JDK 1.6
     */
    public void setStrategyId(Long strategyId) {
        this.strategyId = strategyId;
    }

    /**
     * strategyName.
     *
     * @return the strategyName
     * @since JDK 1.6
     */
    public String getStrategyName() {
        return strategyName;
    }

    /**
     * strategyName.
     *
     * @param strategyName the strategyName to set
     * @since JDK 1.6
     */
    public void setStrategyName(String strategyName) {
        this.strategyName = strategyName;
    }

    /**
     * shieldIndustries.
     *
     * @return the shieldIndustries
     * @since JDK 1.6
     */
    public List<TagLevel> getShieldIndustries() {
        return shieldIndustries;
    }

    /**
     * shieldIndustries.
     *
     * @param shieldIndustries the shieldIndustries to set
     * @since JDK 1.6
     */
    public void setShieldIndustries(List<TagLevel> shieldIndustries) {
        this.shieldIndustries = shieldIndustries;
    }

    /**
     * shieldAdvertisers.
     *
     * @return the shieldAdvertisers
     * @since JDK 1.6
     */
    public List<String> getShieldAdvertisers() {
        return shieldAdvertisers;
    }

    /**
     * shieldAdvertisers.
     *
     * @param shieldAdvertisers the shieldAdvertisers to set
     * @since JDK 1.6
     */
    public void setShieldAdvertisers(List<String> shieldAdvertisers) {
        this.shieldAdvertisers = shieldAdvertisers;
    }

    /**
     * advertTagNums.
     *
     * @return the advertTagNums
     * @since JDK 1.6
     */
    public List<TagLevel> getAdvertTagNums() {
        return advertTagNums;
    }

    /**
     * advertTagNums.
     *
     * @param advertTagNums the advertTagNums to set
     * @since JDK 1.6
     */
    public void setAdvertTagNums(List<TagLevel> advertTagNums) {
        this.advertTagNums = advertTagNums;
    }

    /**
     * flowType.
     *
     * @return the flowType
     * @since JDK 1.6
     */
    public Integer getFlowType() {
        return flowType;
    }

    /**
     * flowType.
     *
     * @param flowType the flowType to set
     * @since JDK 1.6
     */
    public void setFlowType(Integer flowType) {
        this.flowType = flowType;
    }

    /**
     * advertTagNumsFlag.
     *
     * @return the advertTagNumsFlag
     * @since JDK 1.6
     */
    public boolean isAdvertTagNumsFlag() {
        return advertTagNumsFlag;
    }

    /**
     * advertTagNumsFlag.
     *
     * @param advertTagNumsFlag the advertTagNumsFlag to set
     * @since JDK 1.6
     */
    public void setAdvertTagNumsFlag(boolean advertTagNumsFlag) {
        this.advertTagNumsFlag = advertTagNumsFlag;
    }

    public Integer getSlotExposeLimit() {
        return slotExposeLimit;
    }

    public void setSlotExposeLimit(Integer slotExposeLimit) {
        this.slotExposeLimit = slotExposeLimit;
    }

    public Integer getActivityExposeLimit() {
        return activityExposeLimit;
    }

    public void setActivityExposeLimit(Integer activityExposeLimit) {
        this.activityExposeLimit = activityExposeLimit;
    }

    public String getActivityUrl() {
        return activityUrl;
    }

    public void setActivityUrl(String activityUrl) {
        this.activityUrl = activityUrl;
    }

    public String getActivityTargetUrl() {
        return activityTargetUrl;
    }

    public void setActivityTargetUrl(String activityTargetUrl) {
        this.activityTargetUrl = activityTargetUrl;
    }

    public boolean isVisibleOfIco() {
        return isVisibleOfIco;
    }

    public void setVisibleOfIco(boolean visibleOfIco) {
        isVisibleOfIco = visibleOfIco;
    }

    public boolean isVisibleOfCloseButton() {
        return isVisibleOfCloseButton;
    }

    public void setVisibleOfCloseButton(boolean visibleOfCloseButton) {
        isVisibleOfCloseButton = visibleOfCloseButton;
    }

    public String getMsName() {
        return msName;
    }

    public void setMsName(String msName) {
        this.msName = msName;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);

    }

    
    public Boolean getIsReturn() {
        return isReturn;
    }

    
    public void setIsReturn(Boolean isReturn) {
        this.isReturn = isReturn;
    }

    
    public Integer getNumReturn() {
        return numReturn;
    }

    
    public void setNumReturn(Integer numReturn) {
        this.numReturn = numReturn;
    }

    
    public Boolean getIsRecommend() {
        return isRecommend;
    }

    
    public void setIsRecommend(Boolean isRecommend) {
        this.isRecommend = isRecommend;
    }

	public Integer getActivityPutWay() {
		return activityPutWay;
	}

	public void setActivityPutWay(Integer activityPutWay) {
		this.activityPutWay = activityPutWay;
	}

    public List<String> getSdkVersions() {
        return sdkVersions;
    }

    public void setSdkVersions(List<String> sdkVersions) {
        this.sdkVersions = sdkVersions;
    }

    public List<String> getSdkSources() {
        return sdkSources;
    }

    public void setSdkSources(List<String> sdkSources) {
        this.sdkSources = sdkSources;
    }

    public String getSdkType() {
        return sdkType;
    }

    public void setSdkType(String sdkType) {
        this.sdkType = sdkType;
    }

    public Integer getAppStatus() {
        return appStatus;
    }

    public void setAppStatus(Integer appStatus) {
        this.appStatus = appStatus;
    }

    public Integer getDirectMode() {
        return directMode;
    }

    public void setDirectMode(Integer directMode) {
        this.directMode = directMode;
    }

    public List<TagLevel> getShieldActivitys() {
        return shieldActivitys;
    }

    public void setShieldActivitys(List<TagLevel> shieldActivitys) {
        this.shieldActivitys = shieldActivitys;
    }
    
    public boolean isActivitysFlag() {
        return activitysFlag;
    }

    
    public void setActivitysFlag(boolean activitysFlag) {
        this.activitysFlag = activitysFlag;
    }
    
    public Long getManagerStrategyId() {
        return managerStrategyId;
    }

    
    public void setManagerStrategyId(Long managerStrategyId) {
        this.managerStrategyId = managerStrategyId;
    }

    public List<String> getShieldName() {
        return shieldName;
    }

    public void setShieldName(List<String> shieldName) {
        this.shieldName = shieldName;
    }

    public String getPlatform() {
        return platform;
    }

    public void setPlatform(String platform) {
        this.platform = platform;
    }
}

==> ssp-center-api-0.1.37-20171207.035034-2-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/RspSlotBackendDetailDto.java <==
/**
 * Project Name:media-api<br>
 * File Name:RspSlotDetailDto.java<br>
 * Package Name:cn.com.duiba.tuia.media.api.dto.rsp<br>
 * Date:2016年10月14日上午9:45:25<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.List;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName: RspSlotDetailDto <br/>
 * date: 2016年10月14日 上午9:45:26 <br/>
 * .
 *
 * @author xiawei
 * @version
 * @since JDK 1.6
 */
public class RspSlotBackendDetailDto implements Serializable {

    /**
     * @since JDK 1.6
     */
    private static final long serialVersionUID  = -1368433294004913036L;

    /** 广告位ID. */
    private Long              slotId;

    /** 广告位名称. */
    private String            slotName;

    /** 广告位类型. */
    private Integer           slotType;

    /** 媒体ID. */
    private Long              appId;

    /** 媒体名称. */
    private String            appName;

    /** 主图尺寸 0-600*300 1-600*500 2-640*270 3-960*640 4-800*120. */
    private Integer           pictureSize;

    /** 广告信息流类型 */
    private Integer           flowType;

    /** 屏蔽策略ID. */
    private Long              strategyId;

    /** 屏蔽策略名称. */
    private String            strategyName;

    /** 屏蔽行业. */
    private List<TagLevel>    shieldIndustries;

    /** 屏蔽广告主. */
    private List<String>      shieldAdvertisers;

    /** 屏蔽广告列表. */
    private List<TagLevel>    advertTagNums;

    /** 屏蔽活动标签列表 */
    private List<TagLevel>    shieldActivitys;

    /** The industry flag. */
    private boolean           industryFlag      = false;

    /** The advertiser flag. */
    private boolean           advertiserFlag    = false;

    /** The advertTagNums flag. */
    private boolean           advertTagNumsFlag = false;

    /** The activitys flag. */
    private boolean           activitysFlag     = false;

    /** 广告位曝光上限 */
    private Integer           slotExposeLimit;

    /** 活动曝光上限 */
    private Integer           activityExposeLimit;

    /** 手动投放时的活动投放地址. */
    private String            activityUrl;

    /** 手动投放时的活动投放目标地址. */
    private String            activityTargetUrl;

    /** 小图标是否可见. */
    private boolean           isVisibleOfIco;

    /** 关闭按钮是否可见. */
    private boolean           isVisibleOfCloseButton;

    /** 关联规格名称 */
    private String            msName;

    /** 是否拦截返回操作(1:拦截，0:不拦截). */
    private Boolean           isReturn;

    /** 拦截返回操作频次. */
    private Integer           numReturn;

    /** 推荐位弹层开关(1:开，0:关). */
    private Boolean           isRecommend;

    /** 广告位投放方式 */
    private Integer           activityPutWay;

    /** sdk版本list */
    private List<String>      sdkVersions;

    /** sdk来源信息list */
    private List<String>      sdkSources;

    /** sdk类型 */
    private String            sdkType;

    /** app 审核状态 */
    private Integer           appStatus;

    /** 广告位定向模式 1：仅投放定向列表 2：优先投放定向列表 */
    private Integer           directMode;

    /** 管理端屏蔽策略标签 */
    private Long              managerStrategyId;

    /** 来源域名屏蔽策略名称 */
    private List<String>      shieldName;

    /** 媒体平台 */
    private String            platform;

    private String            remark;

    private List<String>      remarkImgs;
    // 广告位性质标签标题
    private String            tagName;

    /** 客服状态 */
    private Integer           isShowService;

    /** 普通插件状态 0 开 1 关 */
    private Integer           commonPlugStatus;
    /** 响应式插件状态 0 开 1 关 */
    private Integer           rspPlugStatus;
    /** 插件优先级 */
    private Integer           rspPlugLevel;
    /** 响应式插件次数 */
    private Integer           rspPlugCount;
    /** 响应式插件Id集合 */
    private List<Long>        rspPlugIds;
    /** 定时插件状态 0 开 1 关 */
    private Integer           timingPlugStatus;
    /** 定时插件Id集合 */
    private List<Long>        timingPlugIds;
    /** 浮标状态 0 开 1 关 */
    private Integer           buoyStatus;
    /** 触发浮标次数 */
    private Integer           buoyCount;

    public Integer getTimingPlugStatus() {
        return timingPlugStatus;
    }

    public void setTimingPlugStatus(Integer timingPlugStatus) {
        this.timingPlugStatus = timingPlugStatus;
    }

    public Integer getCommonPlugStatus() {
        return commonPlugStatus;
    }

    public void setCommonPlugStatus(Integer commonPlugStatus) {
        this.commonPlugStatus = commonPlugStatus;
    }

    public Integer getRspPlugStatus() {
        return rspPlugStatus;
    }

    public void setRspPlugStatus(Integer rspPlugStatus) {
        this.rspPlugStatus = rspPlugStatus;
    }

    public Integer getRspPlugCount() {
        return rspPlugCount;
    }

    public void setRspPlugCount(Integer rspPlugCount) {
        this.rspPlugCount = rspPlugCount;
    }

    public List<Long> getRspPlugIds() {
        return rspPlugIds;
    }

    public void setRspPlugIds(List<Long> rspPlugIds) {
        this.rspPlugIds = rspPlugIds;
    }

    public List<Long> getTimingPlugIds() {
        return timingPlugIds;
    }

    public void setTimingPlugIds(List<Long> timingPlugIds) {
        this.timingPlugIds = timingPlugIds;
    }

    public Integer getBuoyStatus() {
        return buoyStatus;
    }

    public void setBuoyStatus(Integer buoyStatus) {
        this.buoyStatus = buoyStatus;
    }

    public Integer getBuoyCount() {
        return buoyCount;
    }

    public void setBuoyCount(Integer buoyCount) {
        this.buoyCount = buoyCount;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public List<String> getRemarkImgs() {
        return remarkImgs;
    }

    public void setRemarkImgs(List<String> remarkImgs) {
        this.remarkImgs = remarkImgs;
    }

    /**
     * industryFlag.
     *
     * @return the industryFlag
     * @since JDK 1.6
     */
    public boolean isIndustryFlag() {
        return industryFlag;
    }

    /**
     * industryFlag.
     *
     * @param industryFlag the industryFlag to set
     * @since JDK 1.6
     */
    public void setIndustryFlag(boolean industryFlag) {
        this.industryFlag = industryFlag;
    }

    /**
     * advertiserFlag.
     *
     * @return the advertiserFlag
     * @since JDK 1.6
     */
    public boolean isAdvertiserFlag() {
        return advertiserFlag;
    }

    /**
     * advertiserFlag.
     *
     * @param advertiserFlag the advertiserFlag to set
     * @since JDK 1.6
     */
    public void setAdvertiserFlag(boolean advertiserFlag) {
        this.advertiserFlag = advertiserFlag;
    }

    /**
     * slotType.
     *
     * @return the slotType
     * @since JDK 1.6
     */
    public Integer getSlotType() {
        return slotType;
    }

    /**
     * slotType.
     *
     * @param slotType the slotType to set
     * @since JDK 1.6
     */
    public void setSlotType(Integer slotType) {
        this.slotType = slotType;
    }

    /**
     * slotId.
     *
     * @return the slotId
     * @since JDK 1.6
     */
    public Long getSlotId() {
        return slotId;
    }

    /**
     * slotId.
     *
     * @param slotId the slotId to set
     * @since JDK 1.6
     */
    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    /**
     * slotName.
     *
     * @return the slotName
     * @since JDK 1.6
     */
    public String getSlotName() {
        return slotName;
    }

    /**
     * slotName.
     *
     * @param slotName the slotName to set
     * @since JDK 1.6
     */
    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    /**
     * appId.
     *
     * @return the appId
     * @since JDK 1.6
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * appId.
     *
     * @param appId the appId to set
     * @since JDK 1.6
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * appName.
     *
     * @return the appName
     * @since JDK 1.6
     */
    public String getAppName() {
        return appName;
    }

    /**
     * appName.
     *
     * @param appName the appName to set
     * @since JDK 1.6
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }

    /**
     * pictureSize.
     *
     * @return the pictureSize
     * @since JDK 1.6
     */
    public Integer getPictureSize() {
        return pictureSize;
    }

    /**
     * pictureSize.
     *
     * @param pictureSize the pictureSize to set
     * @since JDK 1.6
     */
    public void setPictureSize(Integer pictureSize) {
        this.pictureSize = pictureSize;
    }

    /**
     * strategyId.
     *
     * @return the strategyId
     * @since JDK 1.6
     */
    public Long getStrategyId() {
        return strategyId;
    }

    /**
     * strategyId.
     *
     * @param strategyId the strategyId to set
     * @since JDK 1.6
     */
    public void setStrategyId(Long strategyId) {
        this.strategyId = strategyId;
    }

    /**
     * strategyName.
     *
     * @return the strategyName
     * @since JDK 1.6
     */
    public String getStrategyName() {
        return strategyName;
    }

    /**
     * strategyName.
     *
     * @param strategyName the strategyName to set
     * @since JDK 1.6
     */
    public void setStrategyName(String strategyName) {
        this.strategyName = strategyName;
    }

    /**
     * shieldIndustries.
     *
     * @return the shieldIndustries
     * @since JDK 1.6
     */
    public List<TagLevel> getShieldIndustries() {
        return shieldIndustries;
    }

    /**
     * shieldIndustries.
     *
     * @param shieldIndustries the shieldIndustries to set
     * @since JDK 1.6
     */
    public void setShieldIndustries(List<TagLevel> shieldIndustries) {
        this.shieldIndustries = shieldIndustries;
    }

    /**
     * shieldAdvertisers.
     *
     * @return the shieldAdvertisers
     * @since JDK 1.6
     */
    public List<String> getShieldAdvertisers() {
        return shieldAdvertisers;
    }

    /**
     * shieldAdvertisers.
     *
     * @param shieldAdvertisers the shieldAdvertisers to set
     * @since JDK 1.6
     */
    public void setShieldAdvertisers(List<String> shieldAdvertisers) {
        this.shieldAdvertisers = shieldAdvertisers;
    }

    /**
     * advertTagNums.
     *
     * @return the advertTagNums
     * @since JDK 1.6
     */
    public List<TagLevel> getAdvertTagNums() {
        return advertTagNums;
    }

    /**
     * advertTagNums.
     *
     * @param advertTagNums the advertTagNums to set
     * @since JDK 1.6
     */
    public void setAdvertTagNums(List<TagLevel> advertTagNums) {
        this.advertTagNums = advertTagNums;
    }

    /**
     * flowType.
     *
     * @return the flowType
     * @since JDK 1.6
     */
    public Integer getFlowType() {
        return flowType;
    }

    /**
     * flowType.
     *
     * @param flowType the flowType to set
     * @since JDK 1.6
     */
    public void setFlowType(Integer flowType) {
        this.flowType = flowType;
    }

    /**
     * advertTagNumsFlag.
     *
     * @return the advertTagNumsFlag
     * @since JDK 1.6
     */
    public boolean isAdvertTagNumsFlag() {
        return advertTagNumsFlag;
    }

    /**
     * advertTagNumsFlag.
     *
     * @param advertTagNumsFlag the advertTagNumsFlag to set
     * @since JDK 1.6
     */
    public void setAdvertTagNumsFlag(boolean advertTagNumsFlag) {
        this.advertTagNumsFlag = advertTagNumsFlag;
    }

    public Integer getSlotExposeLimit() {
        return slotExposeLimit;
    }

    public void setSlotExposeLimit(Integer slotExposeLimit) {
        this.slotExposeLimit = slotExposeLimit;
    }

    public Integer getActivityExposeLimit() {
        return activityExposeLimit;
    }

    public void setActivityExposeLimit(Integer activityExposeLimit) {
        this.activityExposeLimit = activityExposeLimit;
    }

    public String getActivityUrl() {
        return activityUrl;
    }

    public void setActivityUrl(String activityUrl) {
        this.activityUrl = activityUrl;
    }

    public String getActivityTargetUrl() {
        return activityTargetUrl;
    }

    public void setActivityTargetUrl(String activityTargetUrl) {
        this.activityTargetUrl = activityTargetUrl;
    }

    public boolean isVisibleOfIco() {
        return isVisibleOfIco;
    }

    public void setVisibleOfIco(boolean visibleOfIco) {
        isVisibleOfIco = visibleOfIco;
    }

    public boolean isVisibleOfCloseButton() {
        return isVisibleOfCloseButton;
    }

    public void setVisibleOfCloseButton(boolean visibleOfCloseButton) {
        isVisibleOfCloseButton = visibleOfCloseButton;
    }

    public String getMsName() {
        return msName;
    }

    public void setMsName(String msName) {
        this.msName = msName;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);

    }

    public Boolean getIsReturn() {
        return isReturn;
    }

    public void setIsReturn(Boolean isReturn) {
        this.isReturn = isReturn;
    }

    public Integer getNumReturn() {
        return numReturn;
    }

    public void setNumReturn(Integer numReturn) {
        this.numReturn = numReturn;
    }

    public Boolean getIsRecommend() {
        return isRecommend;
    }

    public void setIsRecommend(Boolean isRecommend) {
        this.isRecommend = isRecommend;
    }

    public Integer getActivityPutWay() {
        return activityPutWay;
    }

    public void setActivityPutWay(Integer activityPutWay) {
        this.activityPutWay = activityPutWay;
    }

    public List<String> getSdkVersions() {
        return sdkVersions;
    }

    public void setSdkVersions(List<String> sdkVersions) {
        this.sdkVersions = sdkVersions;
    }

    public List<String> getSdkSources() {
        return sdkSources;
    }

    public void setSdkSources(List<String> sdkSources) {
        this.sdkSources = sdkSources;
    }

    public String getSdkType() {
        return sdkType;
    }

    public void setSdkType(String sdkType) {
        this.sdkType = sdkType;
    }

    public Integer getAppStatus() {
        return appStatus;
    }

    public void setAppStatus(Integer appStatus) {
        this.appStatus = appStatus;
    }

    public Integer getDirectMode() {
        return directMode;
    }

    public void setDirectMode(Integer directMode) {
        this.directMode = directMode;
    }

    public List<TagLevel> getShieldActivitys() {
        return shieldActivitys;
    }

    public void setShieldActivitys(List<TagLevel> shieldActivitys) {
        this.shieldActivitys = shieldActivitys;
    }

    public boolean isActivitysFlag() {
        return activitysFlag;
    }

    public void setActivitysFlag(boolean activitysFlag) {
        this.activitysFlag = activitysFlag;
    }

    public Long getManagerStrategyId() {
        return managerStrategyId;
    }

    public void setManagerStrategyId(Long managerStrategyId) {
        this.managerStrategyId = managerStrategyId;
    }

    public List<String> getShieldName() {
        return shieldName;
    }

    public void setShieldName(List<String> shieldName) {
        this.shieldName = shieldName;
    }

    public String getPlatform() {
        return platform;
    }

    public void setPlatform(String platform) {
        this.platform = platform;
    }

    public String getTagName() {
        return tagName;
    }

    public void setTagName(String tagName) {
        this.tagName = tagName;
    }

    public Integer getIsShowService() {
        return isShowService;
    }

    public void setIsShowService(Integer isShowService) {
        this.isShowService = isShowService;
    }

    public Integer getRspPlugLevel() {
        return rspPlugLevel;
    }

    public void setRspPlugLevel(Integer rspPlugLevel) {
        this.rspPlugLevel = rspPlugLevel;
    }
}
